# nomad_connectors_cli
This is the API descriptor for the Nomad Envoy/Pilot API, responsible for order creation and product lists, and shipping and logistics processing

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import nomad_connectors_cli 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import nomad_connectors_cli
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import nomad_connectors_cli
from nomad_connectors_cli.rest import ApiException
from pprint import pprint

configuration = nomad_connectors_cli.Configuration()
# Configure API key authorization: ca_key
configuration.api_key['x-ca-key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-ca-key'] = 'Bearer'
configuration = nomad_connectors_cli.Configuration()
# Configure API key authorization: ca_stage
configuration.api_key['x-ca-stage'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x-ca-stage'] = 'Bearer'

# create an instance of the API class
api_instance = nomad_connectors_cli.CustomsCallbackApi(nomad_connectors_cli.ApiClient(configuration))
store = 'store_example' # str | ID of the store.
body = 'body_example' # str | Order details

try:
    # postCustomsCallback
    api_response = api_instance.post_customs_callback(store, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CustomsCallbackApi->post_customs_callback: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://nomad.samarkand-global.cn/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomsCallbackApi* | [**post_customs_callback**](docs/CustomsCallbackApi.md#post_customs_callback) | **POST** /envoy/customs/{store}/callback | postCustomsCallback
*CustomsOrderApi* | [**post_customs_order**](docs/CustomsOrderApi.md#post_customs_order) | **POST** /envoy/customs/{region}/order | postCustomsOrder
*CustomsPaymentApi* | [**post_customs_payment**](docs/CustomsPaymentApi.md#post_customs_payment) | **POST** /envoy/customs/{region}/payment | postCustomsPayment
*CustomsProductApi* | [**post_customs_product**](docs/CustomsProductApi.md#post_customs_product) | **POST** /envoy/customs/{region}/product | postCustomsProduct
*OrderApi* | [**add_order**](docs/OrderApi.md#add_order) | **POST** /envoy/order/{store} | addOrder
*OrderApi* | [**cancel_order**](docs/OrderApi.md#cancel_order) | **DELETE** /envoy/order/{store} | cancelOrder
*OrderApi* | [**get_order_by_field**](docs/OrderApi.md#get_order_by_field) | **GET** /envoy/order/{store} | getOrderByField
*OrderApi* | [**update_order**](docs/OrderApi.md#update_order) | **PUT** /envoy/order/{store} | updateOrder
*ProductApi* | [**add_product**](docs/ProductApi.md#add_product) | **POST** /envoy/product/{store} | addProduct
*ProductApi* | [**delete_product**](docs/ProductApi.md#delete_product) | **DELETE** /envoy/product/{store} | deleteProduct
*ProductApi* | [**get_products_by_field**](docs/ProductApi.md#get_products_by_field) | **GET** /envoy/product/{store} | getProductsByField
*ProductApi* | [**update_product**](docs/ProductApi.md#update_product) | **PUT** /envoy/product/{store} | updateProduct
*ShipApi* | [**cancel_ship**](docs/ShipApi.md#cancel_ship) | **DELETE** /pilot/ship/{carrier}/order/{order_ref} | cancelShip
*ShipApi* | [**query_ship**](docs/ShipApi.md#query_ship) | **GET** /pilot/ship/{carrier}/order/{order_ref} | queryShip
*ShipApi* | [**ship**](docs/ShipApi.md#ship) | **POST** /pilot/ship/{carrier} | ship


## Documentation For Models

 - [Address](docs/Address.md)
 - [ApiResponse](docs/ApiResponse.md)
 - [ApiResponseConnectorResponse](docs/ApiResponseConnectorResponse.md)
 - [ApiResponseData](docs/ApiResponseData.md)
 - [CustomsDeclarationResult](docs/CustomsDeclarationResult.md)
 - [Dimension](docs/Dimension.md)
 - [Goldjet](docs/Goldjet.md)
 - [Images](docs/Images.md)
 - [Order](docs/Order.md)
 - [OrderProduct](docs/OrderProduct.md)
 - [Package](docs/Package.md)
 - [PackageItem](docs/PackageItem.md)
 - [Product](docs/Product.md)
 - [ProductSku](docs/ProductSku.md)


## Documentation For Authorization


## ca_key

- **Type**: API key
- **API key parameter name**: x-ca-key
- **Location**: HTTP header


## ca_stage

- **Type**: API key
- **API key parameter name**: x-ca-stage
- **Location**: HTTP header


## Author

paul@samarkand.global


